[vlc-devel] [PATCH 1/2] lib: docs: align group_id variable naming

Martin Finkel finkel2804 at gmail.com
Wed Feb 17 09:28:48 UTC 2021


From: Martin Finkel <martin at videolabs.io>

---
 include/vlc/libvlc_media_player.h | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/include/vlc/libvlc_media_player.h b/include/vlc/libvlc_media_player.h
index 77cebe6d57..8951c67b93 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -1540,9 +1540,9 @@ libvlc_player_programlist_delete( libvlc_player_programlist_t *list );
  * \version LibVLC 4.0.0 or later
  *
  * \param p_mi opaque media player handle
- * \param program_id
+ * \param i_group_id program id
  */
-LIBVLC_API void libvlc_media_player_select_program_id( libvlc_media_player_t *p_mi, int program_id);
+LIBVLC_API void libvlc_media_player_select_program_id( libvlc_media_player_t *p_mi, int i_group_id);
 
 /**
  * Get the selected program
@@ -1565,7 +1565,7 @@ libvlc_media_player_get_selected_program( libvlc_media_player_t *p_mi);
  * \param p_mi opaque media player handle
  * \param i_group_id program id
  *
  * \return a valid program struct or NULL if the group_id is not found. The
  * program need to be freed with libvlc_player_program_delete().
  */
 LIBVLC_API libvlc_player_program_t *
@@ -1565,7 +1565,7 @@ libvlc_media_player_get_selected_program( libvlc_media_player_t *p_mi);
  * \param i_group_id program id
  *
- * \return a valid program struct or NULL if the group_id is not found. The
+ * \return a valid program struct or NULL if the i_group_id is not found. The
  * program need to be freed with libvlc_player_program_delete().
  */
-- 
2.25.1.windows.1



More information about the vlc-devel mailing list